__author__ = 'Morgane Bruno'
__licence__ = 'MIT'

## Create file describing demulitplex data
rule demulti__demultiplex_data:
    input:
        config['fichiers']['demultiplex']
    output:
        'results/06_assign_marker_sample_to_sequence/all_demultiplex.csv'
    log:
        'logs/06_assign_marker_sample_to_sequence/demultiplex_files.log'
    conda:
        '../envs/env_scripts_python.yaml'
    params:
        dir_primers_tags = 'results/04_demultiplex_dat/',
        blackl = config['blacklist'],
        dat = config['fichiers']['dat']
    message:
        'Create file describing demulitplex data'
    shell:
        '''
        mkdir -p {params.dir_primers_tags}
        python scripts/write_demultiplex_files.py {input} {output} {params.dir_primers_tags} "{params.blackl}" "{params.dat}" {log} &>> {log}
        '''

## Assign each sequence record to the corresponding sample/marker combination:
rule demulti__ngsfilter:
    input:
        fq = get_input_ngsfilter,
        demulti = rules.demulti__demultiplex_data.output
    output:
        assign = temp('results/06_assign_marker_sample_to_sequence/{demultiplex}.ali.assigned.fastq'),
        unid = Path('results/06_assign_marker_sample_to_sequence/{demultiplex}.unidentified.fastq')
    log:
        'logs/06_assign_marker_sample_to_sequence/{demultiplex}.log'
    conda:
        '../envs/obitools_envs.yaml'
    container:
        config['singularity']['obitools']
    params:
        in_tsv = get_one_pmr
    message:
        'Assign each sequence record: {wildcards.demultiplex}'
    shell:
        '''
        ngsfilter -t {params.in_tsv} -u {output.unid} {input.fq} --fasta-output > {output.assign} 2> {log}
        '''
